@@ -4,7 +4,7 @@ from ctxcore.genesig import GeneSignature
 from GSVA import gsva, gmt_to_dataframe
 import pandas as pd
 import os,sys
-basedir = os.path.abspath(os.path.dirname(sys.argv[0]))
+basedir = os.path.abspath(os.path.dirname(__file__))
 
 def genesets2GeneSig(df: pd.DataFrame) -> Sequence[Type[GeneSignature]]:
     """
@@ -27,23 +27,25 @@ def genesets2GeneSig(df: pd.DataFrame) -> Sequence[Type[GeneSignature]]:
         
     return(GeneSigs)
 
-def KEGG_metabolism() -> pd.DataFrame:
+def metabolism_sigs(resources="KEGG") -> pd.DataFrame:
     """
-    Get a set of default metabolism signature from KEGG. 
+    Get a set of default metabolism signature from KEGG or REACTOME. 
+    :param resources: KEGG or REACTOME, default KEGG
     """
-    df = gmt_to_dataframe(os.path.join(basedir,'sigc', 'resources', 'KEGG_metabolism_nc.gmt'))
-    GeneSigs = genesets2GeneSig(df)
-    return GeneSigs
+    file = "KEGG_metabolism_nc.gmt"
+    if resources=="REACTOME":
+        file = "REACTOME_metabolism.gmt"
+    df = gmt_to_dataframe(os.path.join(basedir,'resources', file))
 
-def REACTOME_metabolism() -> pd.DataFrame:
-    """
-    Get a set of default metabolism signature from REACTOME. 
-    """
-    df = gmt_to_dataframe(os.path.join(basedir, 'sigc','resources', 'REACTOME_metabolism.gmt'))
-    GeneSigs = genesets2GeneSig(df)
-    return GeneSigs
+    return df
+
+def sigc_auc(
+		gene_exp, 
+		GeneSigsDf: pd.DataFrame, 
+		num_workers=4) -> pd.DataFrame:
+
+    GeneSigs = genesets2GeneSig(GeneSigsDf)
 
-def sigc_auc(gene_exp, GeneSigs: Sequence[Type[GeneSignature]], num_workers=4):
     auc_mxt = aucell4r(
         gene_exp,
         GeneSigs,
@@ -54,7 +56,11 @@ def sigc_auc(gene_exp, GeneSigs: Sequence[Type[GeneSignature]], num_workers=4):
 
     return auc_mxt
 
-def sigc_score(ex_mtx: pd.DataFrame, GeneSigs: pd.DataFrame, method="AUCell", num_workers=4) -> pd.DataFrame:
+def sigc_score(
+		ex_mtx: pd.DataFrame, 
+		GeneSigs: pd.DataFrame, 
+		method="AUCell", 
+		num_workers=4) -> pd.DataFrame:
     """
     Get a set of signature score of a given gene expression matrix. 
 
